Scalabel User Guide
====================

Scalabel is an open-source web annotation tool.

.. toctree::
   :maxdepth: 1

   /setup.rst
   /quick-start.rst
   /2d-interface.rst
   /2d-bb.rst
   /instance-segmentation.rst
   /video-tracking.rst
   /keyboard.rst
   /format.rst
   /config.rst
   /tools.rst
   /label.rst
   /auto-label.rst
   /installation.rst


.. For demos, go to:

.. 	- `Overview video <https://go.yf.io/scalabel-video-demo>`__
	.. - `2D Bounding box <https://go.yf.io/scalabel-demo-box2d>`__
	.. - `2D Segmentation <https://go.yf.io/scalabel-demo-seg2d>`__
	.. - `2D Bounding box tracking <https://go.yf.io/scalabel-demo-box2d-tracking>`__
	.. - `2D Segmentation tracking <https://go.yf.io/scalabel-demo-seg2d-tracking>`__
	.. - `2D Lane marking <https://go.yf.io/scalabel-demo-lane>`__
	.. - `3D Bounding box <https://go.yf.io/scalabel-demo-box3d>`__
	.. - `3D Bounding box tracking <https://go.yf.io/scalabel-demo-box3d-tracking>`__
